@@ -1,9 +1,7 @@
 package App::DuckPAN;
-BEGIN {
-  $App::DuckPAN::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: The DuckDuckGo DuckPAN client
-$App::DuckPAN::VERSION = '0.170';
+$App::DuckPAN::VERSION = '0.171';
 use feature 'state';
 
 use Moo;
@@ -103,7 +101,7 @@ option duckpan => (
 sub _ua_string {
   my ($self) = @_;
   my $class   = ref $self || $self;
-  my $version = $class->VERSION;
+  my $version = $class->VERSION || '9.999';
   return "$class/$version";
 }
 
@@ -569,7 +567,7 @@ App::DuckPAN - The DuckDuckGo DuckPAN client
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 DuckPAN
 
