@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd;
-BEGIN {
-  $App::DuckPAN::Cmd::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Base class for commands of DuckPAN
-$App::DuckPAN::Cmd::VERSION = '0.170';
+$App::DuckPAN::Cmd::VERSION = '0.171';
 use Moo::Role;
 
 requires 'run';
@@ -31,7 +29,7 @@ App::DuckPAN::Cmd - Base class for commands of DuckPAN
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
