@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Env;
-BEGIN {
-  $App::DuckPAN::Cmd::Env::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Env command class
-$App::DuckPAN::Cmd::Env::VERSION = '0.170';
+$App::DuckPAN::Cmd::Env::VERSION = '0.171';
 use Moo;
 use MooX::Cmd;
 
@@ -68,7 +66,7 @@ App::DuckPAN::Cmd::Env - Env command class
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
