@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Env::Cmd;
-BEGIN {
-  $App::DuckPAN::Cmd::Env::Cmd::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Base class for Env commands
-$App::DuckPAN::Cmd::Env::Cmd::VERSION = '0.170';
+$App::DuckPAN::Cmd::Env::Cmd::VERSION = '0.171';
 use Moo::Role;
 
 requires 'run';
@@ -37,7 +35,7 @@ App::DuckPAN::Cmd::Env::Cmd - Base class for Env commands
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
