@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Env::Cmd::Get;
-BEGIN {
-  $App::DuckPAN::Cmd::Env::Cmd::Get::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Gets the specified env variable
-$App::DuckPAN::Cmd::Env::Cmd::Get::VERSION = '0.170';
+$App::DuckPAN::Cmd::Env::Cmd::Get::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd::Env::Cmd );
 
@@ -29,7 +27,7 @@ App::DuckPAN::Cmd::Env::Cmd::Get - Gets the specified env variable
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
