@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Env::Cmd::Help;
-BEGIN {
-  $App::DuckPAN::Cmd::Env::Cmd::Help::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: List commands and usage
-$App::DuckPAN::Cmd::Env::Cmd::Help::VERSION = '0.170';
+$App::DuckPAN::Cmd::Env::Cmd::Help::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd::Env::Cmd );
 
@@ -26,7 +24,7 @@ App::DuckPAN::Cmd::Env::Cmd::Help - List commands and usage
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
