@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Env::Cmd::List;
-BEGIN {
-  $App::DuckPAN::Cmd::Env::Cmd::List::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: List all env variables
-$App::DuckPAN::Cmd::Env::Cmd::List::VERSION = '0.170';
+$App::DuckPAN::Cmd::Env::Cmd::List::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd::Env::Cmd );
 
@@ -31,7 +29,7 @@ App::DuckPAN::Cmd::Env::Cmd::List - List all env variables
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
