@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Env::Cmd::Rm;
-BEGIN {
-  $App::DuckPAN::Cmd::Env::Cmd::Rm::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Removes the specified env variable
-$App::DuckPAN::Cmd::Env::Cmd::Rm::VERSION = '0.170';
+$App::DuckPAN::Cmd::Env::Cmd::Rm::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd::Env::Cmd );
 
@@ -30,7 +28,7 @@ App::DuckPAN::Cmd::Env::Cmd::Rm - Removes the specified env variable
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
