@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Env::Cmd::Set;
-BEGIN {
-  $App::DuckPAN::Cmd::Env::Cmd::Set::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Sets the specified env variable value
-$App::DuckPAN::Cmd::Env::Cmd::Set::VERSION = '0.170';
+$App::DuckPAN::Cmd::Env::Cmd::Set::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd::Env::Cmd );
 
@@ -32,7 +30,7 @@ App::DuckPAN::Cmd::Env::Cmd::Set - Sets the specified env variable value
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
