@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Help;
-BEGIN {
-  $App::DuckPAN::Cmd::Help::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Launch help page
-$App::DuckPAN::Cmd::Help::VERSION = '0.170';
+$App::DuckPAN::Cmd::Help::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -30,7 +28,7 @@ App::DuckPAN::Cmd::Help - Launch help page
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
