@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Install;
-BEGIN {
-  $App::DuckPAN::Cmd::Install::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Install the distribution in current directory
-$App::DuckPAN::Cmd::Install::VERSION = '0.170';
+$App::DuckPAN::Cmd::Install::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -34,7 +32,7 @@ App::DuckPAN::Cmd::Install - Install the distribution in current directory
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
