@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::New;
-BEGIN {
-  $App::DuckPAN::Cmd::New::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Take a name as input and generates a new, named Goodie or Spice instant answer skeleton
-$App::DuckPAN::Cmd::New::VERSION = '0.170';
+$App::DuckPAN::Cmd::New::VERSION = '0.171';
 # For Goodies:
 # 	- <name>.pm file is created in lib/DDG/Goodie
 #
@@ -95,7 +93,7 @@ App::DuckPAN::Cmd::New - Take a name as input and generates a new, named Goodie
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
