@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Poupload;
-BEGIN {
-  $App::DuckPAN::Cmd::Poupload::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Command for uploading .po files to the DuckDuckGo Community Platform
-$App::DuckPAN::Cmd::Poupload::VERSION = '0.170';
+$App::DuckPAN::Cmd::Poupload::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -74,7 +72,7 @@ App::DuckPAN::Cmd::Poupload - Command for uploading .po files to the DuckDuckGo
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
