@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Publisher;
-BEGIN {
-  $App::DuckPAN::Cmd::Publisher::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Starting up the publisher test webserver
-$App::DuckPAN::Cmd::Publisher::VERSION = '0.170';
+$App::DuckPAN::Cmd::Publisher::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -81,7 +79,7 @@ App::DuckPAN::Cmd::Publisher - Starting up the publisher test webserver
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
