@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Query;
-BEGIN {
-  $App::DuckPAN::Cmd::Query::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Command line tool for testing queries and see triggered instant answers
-$App::DuckPAN::Cmd::Query::VERSION = '0.170';
+$App::DuckPAN::Cmd::Query::VERSION = '0.171';
 use MooX;
 with qw( App::DuckPAN::Cmd App::DuckPAN::Restart );
 
@@ -39,7 +37,7 @@ App::DuckPAN::Cmd::Query - Command line tool for testing queries and see trigger
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
