@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Release;
-BEGIN {
-  $App::DuckPAN::Cmd::Release::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Release the distribution of the current directory
-$App::DuckPAN::Cmd::Release::VERSION = '0.170';
+$App::DuckPAN::Cmd::Release::VERSION = '0.171';
 use MooX;
 with qw( App::DuckPAN::Cmd );
 
@@ -31,7 +29,7 @@ App::DuckPAN::Cmd::Release - Release the distribution of the current directory
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
