@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Roadrunner;
-BEGIN {
-  $App::DuckPAN::Cmd::Roadrunner::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Install requirements as fast as possible
-$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.170';
+$App::DuckPAN::Cmd::Roadrunner::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -46,7 +44,7 @@ App::DuckPAN::Cmd::Roadrunner - Install requirements as fast as possible
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
