@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Server;
-BEGIN {
-  $App::DuckPAN::Cmd::Server::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Starting up the web server to test instant answers
-$App::DuckPAN::Cmd::Server::VERSION = '0.170';
+$App::DuckPAN::Cmd::Server::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd App::DuckPAN::Restart );
 
@@ -436,7 +434,7 @@ App::DuckPAN::Cmd::Server - Starting up the web server to test instant answers
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
