@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Setup;
-BEGIN {
-  $App::DuckPAN::Cmd::Setup::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Setting up your duck.co Account on your duckpan client
-$App::DuckPAN::Cmd::Setup::VERSION = '0.170';
+$App::DuckPAN::Cmd::Setup::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::Cmd );
 
@@ -179,7 +177,7 @@ App::DuckPAN::Cmd::Setup - Setting up your duck.co Account on your duckpan clien
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
