@@ -1,9 +1,7 @@
 package App::DuckPAN::Cmd::Test;
-BEGIN {
-  $App::DuckPAN::Cmd::Test::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Command for running the tests of this library
-$App::DuckPAN::Cmd::Test::VERSION = '0.170';
+$App::DuckPAN::Cmd::Test::VERSION = '0.171';
 use MooX;
 with qw( App::DuckPAN::Cmd );
 
@@ -37,7 +35,7 @@ App::DuckPAN::Cmd::Test - Command for running the tests of this library
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
