@@ -1,9 +1,7 @@
 package App::DuckPAN::Config;
-BEGIN {
-  $App::DuckPAN::Config::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Configuration class of the duckpan client
-$App::DuckPAN::Config::VERSION = '0.170';
+$App::DuckPAN::Config::VERSION = '0.171';
 use Moo;
 use File::HomeDir;
 use Path::Tiny;
@@ -58,7 +56,7 @@ App::DuckPAN::Config - Configuration class of the duckpan client
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
