@@ -1,9 +1,7 @@
 package App::DuckPAN::DDG;
-BEGIN {
-  $App::DuckPAN::DDG::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: DDG related functionality of duckpan
-$App::DuckPAN::DDG::VERSION = '0.170';
+$App::DuckPAN::DDG::VERSION = '0.171';
 use Moo;
 with 'App::DuckPAN::HasApp';
 
@@ -138,7 +136,7 @@ App::DuckPAN::DDG - DDG related functionality of duckpan
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
