@@ -1,9 +1,7 @@
 package App::DuckPAN::HasApp;
-BEGIN {
-  $App::DuckPAN::HasApp::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Simple role for classes which carry an object of App::DuckPAN
-$App::DuckPAN::HasApp::VERSION = '0.170';
+$App::DuckPAN::HasApp::VERSION = '0.171';
 use Moo::Role;
 
 has app => (
@@ -23,7 +21,7 @@ App::DuckPAN::HasApp - Simple role for classes which carry an object of App::Duc
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
