@@ -1,9 +1,7 @@
 package App::DuckPAN::Query;
-BEGIN {
-  $App::DuckPAN::Query::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Main application/loop for duckpan query
-$App::DuckPAN::Query::VERSION = '0.170';
+$App::DuckPAN::Query::VERSION = '0.171';
 use Moo;
 use Data::Printer;
 use POE qw( Wheel::ReadLine );
@@ -142,7 +140,7 @@ App::DuckPAN::Query - Main application/loop for duckpan query
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
