@@ -1,9 +1,7 @@
 package App::DuckPAN::Restart;
-BEGIN {
-  $App::DuckPAN::Restart::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Automatic restarting of application on file change
-$App::DuckPAN::Restart::VERSION = '0.170';
+$App::DuckPAN::Restart::VERSION = '0.171';
 use File::Find::Rule;
 use Filesys::Notify::Simple;
 
@@ -119,7 +117,7 @@ App::DuckPAN::Restart - Automatic restarting of application on file change
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
