@@ -1,9 +1,7 @@
 package App::DuckPAN::Web;
-BEGIN {
-  $App::DuckPAN::Web::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan server
-$App::DuckPAN::Web::VERSION = '0.170';
+$App::DuckPAN::Web::VERSION = '0.171';
 use Moo;
 use DDG::Request;
 use DDG::Test::Location;
@@ -206,6 +204,7 @@ sub request {
 		my @calls_nrc = ();
 		my @calls_script = ();
 		my %calls_template = ();
+		my @calls_goodie;
 
 		for (@{$self->blocks}) {
 			push(@results,$_->request($ddg_request));
@@ -238,7 +237,6 @@ sub request {
 				HTML::TreeBuilder->new_from_content("<script type=\"text/javascript\">seterr('$error')</script>")->guts
 			);
 			p($error, color => { string => 'red' });
-			$page = $root->as_HTML;
 		}
 
 		# Iterate over results,
@@ -255,7 +253,8 @@ sub request {
 			my $result_type =	($res_ref eq 'DDG::ZeroClickInfo::Spice') ? 'spice' :
 								($res_ref eq 'DDG::ZeroClickInfo') ?		'goodie' :
 																			'other';
-			if (($result_type eq 'spice' || $result_type eq 'goodie')
+			my $is_goodie = $result_type eq 'goodie';
+			if (($result_type eq 'spice' || $is_goodie)
 				&& $result->caller->can('module_share_dir')) {
 				# grab associated JS, Handlebars and CSS
 				# and add them to correct arrays for injection into page
@@ -278,9 +277,8 @@ sub request {
 					}
 				}
 				push (@calls_nrj, $result->call_path) if ($result->can('call_path'));
-
 			}
-			if ($result_type eq 'goodie'){
+			if ($is_goodie){
 				# We have a Goodie result so modify HTML and return content
 				# Grab ZCI div, push in required HTML
 				my $zci_container = HTML::Element->new('div', id => "zci-answer", class => "zci zci--answer is-active");
@@ -288,11 +286,17 @@ sub request {
 					# Inject a script which prints out what we want.
 					# There is no error-checking or support for non-auto-templates here.
 					my $structured = $result->structured_answer;
-					my $template_name = 'goodie_'.scalar @{$structured->{input}}.'_inputs';
-					my $json_string = encode_json({Answer => $structured});
-					$zci_container->push_content(HTML::TreeBuilder->new_from_content("<script>\$(window).load(function(){"
-								. "document.getElementById('zci-answer').innerHTML = DDG.exec_template('$template_name', $json_string);"
-								. "});</script>")->guts);
+					if(exists $structured->{templates}){ # user-specified templates
+						push @calls_goodie, $structured;
+						last;
+					}
+					else{ # auto-template
+						my $template_name = 'goodie_'.scalar @{$structured->{input}}.'_inputs';
+						my $json_string = encode_json({Answer => $structured});
+						$zci_container->push_content(HTML::TreeBuilder->new_from_content("<script>\$(window).load(function(){"
+							. "document.getElementById('zci-answer').innerHTML = DDG.exec_template('$template_name', $json_string);"
+							. "});</script>")->guts);
+					}
 				} else {
 					$zci_container->push_content(
 						HTML::TreeBuilder->new_from_content(
@@ -335,10 +339,9 @@ sub request {
 
 				my $html = $root->look_down(_tag => "html");
 				$html->attr(class => "set-header--fixed  has-zcm js no-touch csstransforms3d csstransitions svg use-opts has-active-zci");
-
+				
 				# Make sure we only show one Goodie (this will change down the road)
 				last;
-
 			}
 			if ($result_type eq 'other') {
 				# Not Spice or Goodie, inject raw Dumper() output from into page
@@ -351,17 +354,27 @@ sub request {
 			}
 		}
 
-		# Setup various script tags:
-		#   calls_script : spice js files
-		#   calls_nrj : proxied spice api calls
-		#   calls_nrc : spice css calls
-		#   calls_template : spice handlebars templates
+		# Setup various script tags for IAs that can template:
+		#   calls_script : js files
+		#   calls_nrj : proxied spice api calls or goodie future
+		#   calls_nrc : css calls
+		#   calls_template : handlebars templates
 
-		my $calls_nrj = (scalar @calls_nrj) ? join(";",map { "nrj('".$_."')" } @calls_nrj) . ';' : '';
-		my $calls_nrc = (scalar @calls_nrc) ? join(";",map { "nrc('".$_."')" } @calls_nrc) . ';' : '';
-		my $calls_script = (scalar @calls_script)
-			? join("",map { "<script type='text/JavaScript' src='".$_."'></script>" } @calls_script)
-			: '';
+		my ($calls_nrj, $calls_script);
+		# For now we only allow a single goodie. If that changes, we will do the
+		# same join/map as with spices.
+		if(@calls_goodie){
+			my $goodie = shift @calls_goodie;
+			$calls_nrj = "DDG.duckbar.future_signal_tab({signal:'high',from:'$goodie->{id}'});",
+			$calls_script = q|<script type="text/JavaScript" class="script-run-on-ready">/*DDH.add(| . encode_json($goodie) . q|);*/</script>|
+		}
+		else{
+			$calls_nrj = @calls_nrj ? join(';', map { "nrj('".$_."')" } @calls_nrj) . ';' : '';
+			$calls_script = @calls_script
+				? join('',map { "<script type='text/JavaScript' src='".$_."'></script>" } @calls_script)
+				: '';
+		}
+		my $calls_nrc = @calls_nrc ? join(';', map { "nrc('".$_."')" } @calls_nrc) . ';' : '';
 
 		if (%calls_template) {
 			foreach my $spice_name ( keys %calls_template ){
@@ -412,7 +425,7 @@ App::DuckPAN::Web - Webserver for duckpan server
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
