@@ -1,9 +1,7 @@
 package App::DuckPAN::WebPublisher;
-BEGIN {
-  $App::DuckPAN::WebPublisher::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan publisher
-$App::DuckPAN::WebPublisher::VERSION = '0.170';
+$App::DuckPAN::WebPublisher::VERSION = '0.171';
 use Moo;
 with qw( App::DuckPAN::HasApp );
 
@@ -110,7 +108,7 @@ App::DuckPAN::WebPublisher - Webserver for duckpan publisher
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
