@@ -1,9 +1,7 @@
 package App::DuckPAN::WebStatic;
-BEGIN {
-  $App::DuckPAN::WebStatic::AUTHORITY = 'cpan:DDG';
-}
+our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Webserver for duckpan static
-$App::DuckPAN::WebStatic::VERSION = '0.170';
+$App::DuckPAN::WebStatic::VERSION = '0.171';
 use Moo;
 use HTTP::Request;
 use Plack::Request;
@@ -109,7 +107,7 @@ App::DuckPAN::WebStatic - Webserver for duckpan static
 
 =head1 VERSION
 
-version 0.170
+version 0.171
 
 =head1 AUTHOR
 
